From 7d8b38c441a0281bfad0db94d961965c36f89241 Mon Sep 17 00:00:00 2001
From: Eric Kooistra <kooistra@astron.nl>
Date: Thu, 22 Feb 2024 10:23:37 +0100
Subject: [PATCH] Use c_sdp_bdo_reorder_nof_blocks_max = 16 as a better
 compromis.

---
 .../lofar2/libraries/sdp/src/vhdl/sdp_bdo_pkg.vhd    | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/applications/lofar2/libraries/sdp/src/vhdl/sdp_bdo_pkg.vhd b/applications/lofar2/libraries/sdp/src/vhdl/sdp_bdo_pkg.vhd
index d19cf03a6b..1dd450cdd7 100644
--- a/applications/lofar2/libraries/sdp/src/vhdl/sdp_bdo_pkg.vhd
+++ b/applications/lofar2/libraries/sdp/src/vhdl/sdp_bdo_pkg.vhd
@@ -60,16 +60,16 @@ package sdp_bdo_pkg is
   -- the reordering. Therefore c_sdp_bdo_reorder_nof_blocks_max = 16 is a
   -- suitable compromise value.
   -- Conclusion (14 feb 2024):
   -- . Choose c_sdp_bdo_reorder_nof_blocks_max = 4 to save block RAM resources,
   --   and because it is acceptable to have smaller packets in case of more
   --   than 4 destinations. Note that the reorder buffer is dual page.
   -- . Choose nof_bdo_destinations_max = 8 in design revision, because it is
   --   enough for CEP, and to save logic resources and to ease timing closure.
-  constant c_sdp_bdo_reorder_nof_blocks_max : natural := 4;
+  constant c_sdp_bdo_reorder_nof_blocks_max : natural := 16;
   constant c_sdp_bdo_reorder_nof_blocks_w   : natural := ceil_log2(c_sdp_bdo_reorder_nof_blocks_max + 1);
   constant c_sdp_bdo_reorder_nof_ch_max     : natural := c_sdp_bdo_reorder_nof_blocks_max *
                                                          c_sdp_nof_beamlets_per_block *
-                                                         c_sdp_nof_words_per_beamlet;  -- = 4 * 488 * 1 = 1952 32b
+                                                         c_sdp_nof_words_per_beamlet;  -- = 16 * 488 * 1 = 7808 32b
 
   -- 32 * 3 + 4 = 100 fields
   constant c_sdp_bdo_destinations_info_nof_hdr_fields : natural := c_sdp_bdo_mm_nof_destinations_max * 3 + 4;
@@ -60,16 +60,16 @@ package sdp_bdo_pkg is
   -- suitable compromise value.
   -- Conclusion (14 feb 2024):
-  -- . Choose c_sdp_bdo_reorder_nof_blocks_max = 4 to save block RAM resources,
-  --   and because it is acceptable to have smaller packets in case of more
-  --   than 4 destinations. Note that the reorder buffer is dual page.
-  -- . Choose nof_bdo_destinations_max = 8 in design revision, because it is
+  -- . Choose c_sdp_bdo_reorder_nof_blocks_max = 16 to save block RAM
+  --   resources, and because it is acceptable to have smaller packets in case
+  --   of more than 4 destinations. Note that the reorder buffer is dual page.
+  -- . Choose nof_bdo_destinations_max = 16 in design revision, because it is
   --   enough for CEP, and to save logic resources and to ease timing closure.
-- 
GitLab